@@ -86,3 +86,10 @@ st_as_sfc.character = function(x, crs = NA_integer_, ...) {
 		ret
 	}
 }
+#' @name st_as_sfc
+#' @details if \code{x} is a \code{factor}, it is converted to \code{character}
+#' @export
+st_as_sfc.factor = function(x, ...) {
+	x = as.character(x)
+	NextMethod()
+}
