@@ -83,3 +83,7 @@ out %>% summarise(mean(new_dens))
 # total densities don't:
 nc.merc %>% summarise(sum(area * dens))
 out %>% summarise(sum(A * new_dens))
+
+conn = system.file("gpkg/nc.gpkg", package = "sf")
+db = src_sqlite(conn)
+tbl(db, "nc.gpkg") %>% filter(AREA > 0.2) %>% collect %>% st_sf
