@@ -17,7 +17,8 @@ test_that("st_crs works", {
 
   expect_warning(st_crs(nc2) <- 3857, "replacing crs does not reproject data")
   expect_silent(st_crs(nc2) <- 3857)
-  expect_warning(st_crs(nc2) <- 0, "Failed to lookup UOM CODE")
+  #expect_warning(st_crs(nc2) <- 0, "Failed to lookup UOM CODE") -> changes in gdal 2.2:
+  expect_warning(st_crs(nc2) <- 0)
   expect_warning(st_crs(nc2) <- 1000, "not found in EPSG")
   expect_silent(st_crs(nc1) <- st_crs(nc1))
 
